/*
 *
 *  logger.c -- log arbitrary system messages
 *
 *  Steven Winikoff
 *  1991/06/12
 *  Anne Bennett
 *  1993/09/09
 *  1993/10/14
 *
 *  This program shouldn't be necessary, but it is.  It allows messages
 *  to be written to the log maintained by syslogd(8).
 *
 *  usage:    logger [-p priority] msg
 *
 *            where "msg" is any arbitrary string, quoted if it contains
 *            spaces or metacharacters, and priority can be a
 *            facility.level pair or just the level, either numeric
 *            or text.
 *
 *  The message will be logged at a priority of "LOG_NOTICE", which has
 *  a numeric value of 7, and using the facility "LOG_COMPAT".  Process ID
 *  will be logged ("LOG_PID" flag).
 *
 */

/* Using the new logger; change header file location */
#include <strings.h>
#include <stdio.h>
#define SYSLOG_NAMES
#include "syslog.h"

#define DEFAULT_PRIORITY LOG_NOTICE
#define DEFAULT_FACILITY LOG_COMPAT
#define FLAGS LOG_PID


int mapname (givenstring, namemap)
char *givenstring;   /* string to be mapped to an integer */
CODE namemap[];  /* either facilitynames or prioritynames as per syslog.h */
{
   int j = 0;

   while (namemap[j].c_name != NULL ) {
      if (strcmp(namemap[j].c_name, givenstring) == 0) {
	 return namemap[j].c_val;
      }
      j++;
   }
   return (-1);
}



main (argc, argv)
char *argv[];
int  argc;
{
   int facility;
   int priority;
   int flags = FLAGS;
   char *dotptr;
   char *facstring;
   char *pristring;
   char *message;


   /* Let's parse the arguments */
   if ( (argc != 2) && (argc != 4) ) {
      fprintf(stderr, "usage:  logger [-p [facility.]level] msg\n");
      exit(1);
   }
   if ( (argc == 4) && (strcmp(argv[1], "-p") != 0) ) {
      fprintf(stderr, "usage:  logger [-p [facility.]level] msg\n");
      exit(1);
   }

   if (argc == 2) {     /* using default priority */
      facility = DEFAULT_FACILITY;
      priority = DEFAULT_PRIORITY;
      message = argv[1];
   }
   else {               /* parse the priority */
      message = argv[3];
      /* figure out whether the argument is level or facility.level */
      /*  and if the latter split them out.                         */


      if ( dotptr = strchr(argv[2],'.') ) {
	 /* A two-part argument */
	 *dotptr = '\0'; /* splits argv[2] into two substrings */
	 pristring = ++dotptr; /* string starts after new null */
	 priority = mapname(pristring,prioritynames);
	 facstring = argv[2];
	 facility = mapname(facstring,facilitynames);
      }
      else {
	 /* A one-part argument */
	 pristring = argv[2];
	 priority = mapname(pristring,prioritynames);
	 facility = DEFAULT_FACILITY;
      }

      if ( facility == -1 ) {
	 fprintf(stderr, "logger: error, facility %s unrecognized.\n", facstring);
         exit(1);
      }
      if ( priority == -1 ) {
	 fprintf(stderr, "logger: error, priority %s unrecognized.\n", pristring);
         exit(1);
      }

   }

   openlog("logger", flags, facility);
   syslog(priority, "%s", message);
   closelog();

   return 0;
} /* end main */
