.\" @(#)newsyslog.conf.5 1998/02/24 Sylvain Robitaille, Concordia University.
.\"
.TH NEWSYSLOG.CONF 5 "23 February 1998"
.SH NAME
newsyslog.conf \- Configuration file for newsyslog.
.SH SYNOPSIS
frequency:log file:backup dir:backup file:pid file:compress:cycles
.SH DESCRIPTION
The \fBnewsyslog.conf\fP file maps log file names to the parameters under
which backups (old generations) of each are kept.
.PP
Entries in this file consist of seven colon separated fields on a line.
Whitespace is permitted on either side of each field to aid readability.
Blank lines and comment lines (lines whose first non-whitespace
character is a pound sign (#)) are silently ignored.
.PP
All paths in configuration entries must be absolute, that is, they must
begin with a slash (/) and contain the full path to the file in
question. Any path which does not meet this requirement is an error and
will be reported as such. Lines containing errors are skipped.
.PP
Some fields are optional, (these are indicated below), and though they
may be left blank, the fields themselves (as defined by
the presence of leading and trailing colons) must exist. Entries in the
configuration file which don't have the correct number of fields will be
reported as erroneous and skipped.
.SH FIELDS
.TP
\fBfrequency\fP:
An arbitrary text string which will match the \fIfrequency\fP
parameter on the command line to the program. For example, if
the call to newsyslog is \fInewsyslog foo\fP, any entries in the
newsyslog.conf file with a frequency of \fIfoo\fP will be matched
and processed.
.TP
\fBlog file\fP:
The absolute path to the file which is to be rotated.
.TP
\fBbackup dir\fP:
(Optional) The path to the directory where previous
generations of \fIlog file\fP are to be kept. If this field is
left blank, the program defaults to the same directory as
\fIlog file\fP.
.TP
\fBNOTE\fP
If the backup directory defaults to
a symbolic link, it is considered erroneous as the real
intended backup directory for this entry cannot be clearly
discerned.
.TP
\fBbackup file\fP:
(Optional) The filename to use for the backup file. The
backup file will always get an additional extension of
either a number or a numeric representation of the date,
depending on how \fIcycles\fP (see below) is configured.

If this field is empty, the program defaults to using the
basename of \fIlog file\fP, which will be suitable for
most situations.
.TP
\fBpid file\fP:
(Optional) The path to the file which contains the
process id of the process which "owns" \fIlog file\fP.
When all files belonging to the process id in
this file have been moved aside, and new ones created to
replace them, the process will be sent a \fBHUP\fP signal,
causing it to begin logging to the new files. This field
defaults to \fInone\fP if left blank, and no process is sent a
signal after the file has been moved.
.TP
\fBcompress\fP:
(Optional) The (case insensitive) string \fBcompress\fP in this
field indicates to the program that the backup of the log
file should be compressed once it has been successfully
moved into place in the backup directory. The compression program to
use can be configured in the source, but the default is to use
.MS gzip 1
which is likely to be available on most systems.

If the \fIcompress\fP field is left blank, the program performs
no compression on backup files.
.TP
\fBcycles\fP:
Either a number or a special keyword; see below.

If this field is an integer, it represents the number of cycles of
backups of \fIlog file\fP to keep in
the backup directory. When the backup files are rotated,
only this many of the most recent files will be kept. (ie.:
to keep a week's worth of log files that are rotated daily,
set \fIcycles\fP to 7).

An alternative use of \fIcycles\fP is to have an unlimited number
of files kept by the date on which the rotation occured.
This is accomplished by using one of the keywords \fBdate\fP,
\fIdate-yesterday\fP, \fIdate-yestermonth\fP, or \fIdate-time\fP in the
\fIcycles\fP field. This results in a numeric filename extension which
encodes a date, as follows:
.TP
\fIdate\fP:
Use the current date, in the form \fBYYYYMMDD\fP.
.TP
\fIdate-yesterday\fP:
Use yesterday's date instead of today's to figure the backup file
extension, again as \fBYYYYMMDD\fP.
.TP
\fIdate-yestermonth\fP:
Create the file extension using only the year and month of the
\fBprevious\fP month, such as \fBYYYYMM\fP.
.TP
\fIdate-time\fP:
Encode the current time into the filename extension as well as the date.
.SH "SEE ALSO"
.MS newsyslog 8
.SH AUTHOR
Sylvain Robitaille, Concordia University, Montreal, Canada.
